NAME
Geo::StormTracker - Perl bundle for working with national weather advisories
SYNOPSIS
See documentation of each module of the bundle. This currently includes the following:
Geo::StormTracker::Main
Geo::StormTracker::Data
Geo::StormTracker::Advisory
Geo::StormTracker::Parser
DESCRIPTION
The Storm-Tracker perl bundle is designed to track weather events using the national weather advisories. The original intent is to track tropical depressions, storms and hurricanes.
AUTHOR
James Lee Carpenter, Jimmy.Carpenter@chron.com
All rights reserved. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
Thanks to Dr. Paul Ruscher for his assistance in helping me to understand the weather advisory formats.
SEE ALSO
Geo::StormTracker::Advisory
Geo::StormTracker::Parser
Geo::StormTracker::Main
Geo::StormTracker::Data
perl(1).